==> kmymoney2-trinity_3.5.13.2.orig.tar.xz: kmymoney-trinity-3.5.13.2/kmymoney2/dialogs/kbackupdlg.h <==
/***************************************************************************
                          kbackupdialog.h  -  description
                             -------------------
    begin                : Mon Jun 4 2001
    copyright            : (C) 2001 by Michael Edwardes
    email                : mte@users.sourceforge.net
                             Javier Campos Morales <javi_c@ctv.es>
                             Felix Rodriguez <frodriguez@mail.wesleyan.edu>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KBACKUPDIALOG_H
#define KBACKUPDIALOG_H

#include <tqwidget.h>
#include "../dialogs/kbackupdlgdecl.h"

/**
  *@author Michael Edwardes
  */

class KBackupDlg : public kbackupdlgdecl  {
	Q_OBJECT
  TQ_OBJECT
private:
  void readConfig(void);
  void writeConfig(void);

protected slots:
  void chooseButtonClicked();

public:
	KBackupDlg( TQWidget* parent,  const char* name/*, bool modal*/);
	~KBackupDlg();
};

#endif

==> kmymoney2-trinity_14.1.0.orig.tar.xz: kmymoney-trinity-14.1.0/kmymoney2/dialogs/kbackupdlg.h <==
/***************************************************************************
                          kbackupdialog.h  -  description
                             -------------------
    begin                : Mon Jun 4 2001
    copyright            : (C) 2001 by Michael Edwardes
    email                : mte@users.sourceforge.net
                             Javier Campos Morales <javi_c@ctv.es>
                             Felix Rodriguez <frodriguez@mail.wesleyan.edu>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KBACKUPDIALOG_H
#define KBACKUPDIALOG_H

#include <tqwidget.h>
#include "kbackupdlgdecl.h"

/**
  *@author Michael Edwardes
  */

class KBackupDlg : public kbackupdlgdecl  {
	Q_OBJECT
  
private:
  void readConfig(void);
  void writeConfig(void);

protected slots:
  void chooseButtonClicked();

public:
	KBackupDlg( TQWidget* parent,  const char* name/*, bool modal*/);
	~KBackupDlg();
};

#endif
